#!/usr/bin/env python3
# -*- coding: utf-8 -*-
from configuration import *
from gestionOMS import *
from gestion_unites import *

import matplotlib.pyplot as plt

def cree_figure(conf,l_jours,l_poids,liste_err):
    debug("debut de cree_figure",liste_err)
    try:
        liste_data_labels_p,liste_data_labels_z = renvoie_liste_labels(conf,liste_data_choisie_p,liste_data_choisie_z,liste_err)
    except:
        erreur("bug avec liste data labels",liste_err)
        return ""

    if conf["maxi"] ==0:
        if l_jours != []:
            jour_maxi = max(l_jours)# pas la peine d'aller très au delà du jour max
            jour_maxi = int(jour_maxi* 1.1)+3 # on rajoute un peu
        else:
            jour_maxi = CONFIG["jours_defaut_donneesvides"] # si pas de données, arbitrairement on met ça
    else:
        jour_maxi = conf["maxi"]+1
        

    # On s'assure que c'est bien compris dans les bornes
    jour_maxi = max(CONFIG["jours_mini_courbe"],min(jour_maxi,CONFIG["jours_maxi_courbe"]))
    debug("cree_figure : gestion du jour max ok : "+str(jour_maxi),liste_err)    
    
    if conf["unite"] == "":
        conf["unite"] = choix_unite(jour_maxi)
        
    l_jours_conv = convertit_tableau(l_jours,conf["unite"],liste_err)
    # Attention, comme les jours commencent à partir de 0, faut enlever 1 pour avoir la borne...
    age_maxi = convertitunite(jour_maxi-1,conf["unite"],liste_err)
    
    debug("cree_figure : conversion des unités ok",liste_err)        

    titre = "Courbe de poids OMS"
    
    if conf["typecourbe"] == "P":
        # percentiles
        liste_data_labels = liste_data_labels_p
        if conf["sexe"] == "M":
            fichier_oms = f_poids_perc_garcon
            titre  += " (percentiles, garçon)"
        elif conf["sexe"] == "F":
            fichier_oms = f_poids_perc_fille
            titre += " (percentiles, fille)"
        else:
            fichier_oms = f_poids_perc_mixte
            titre += " (percentiles)"
    elif conf["typecourbe"] == "Z":
        liste_data_labels = liste_data_labels_z
        if conf["sexe"] == "G":
            fichier_oms = f_poids_z_garcon
            titre += " (moyenne et écarts-types, garçon)"
        elif conf["sexe"] == "F":
            fichier_oms = f_poids_z_fille
            titre += " (moyenne et écarts-types, fille)"
        else:
            fichier_oms = f_poids_z_mixte
            titre += " (moyenne et écarts-types)"
    else:
        erreur("Type de courbe invalide"+conf["typecourbe"],liste_err)
        return ""
   
    debug("cree_figure : géré le type de courbe ok",liste_err)         
    
    # Si y'a un nom on met "courbe de machin"
    if conf["nom"] !="":
        titre += " de " +conf["nom"]
        
    
    # convertir les unités
    
    #### On extrait les données des courbes, et on convertit les jours dans l'unité voulues
    try:
        t = lire_fichier_csv(fichier_oms)
    except:
        liste_err[0].append("Impossible d'ouvrir le fichier "+fichier_oms)
        return ""
    
    debug("cree_figure : on va convertir données OMS à la bonne unité",liste_err)
    try:   
        coljour = convertit_tableau(extraire_colonne(t,0,jour_maxi),conf["unite"],liste_err)
    except:
        erreur("Problème à la conversion du tableau OMS. jour_maxi = "+str(jour_maxi)+" unite = "+unite,liste_err)
        return ""
    
    debug("cree_figure : prête à créer la figure",liste_err)   
    #### La figure
    fig = plt.figure(num=None, figsize=(conf["largeur"], conf["hauteur"]), dpi=100, facecolor=conf["couleurs"]["fond"])
    plt.rcParams['axes.facecolor'] = conf["couleurs"]["fond"]
    plt.rcParams['axes.edgecolor']= conf["couleurs"]["cadretxt"]
    plt.rcParams['xtick.color'] = conf["couleurs"]["cadretxt"]
    plt.rcParams['ytick.color'] = conf["couleurs"]["cadretxt"]
    plt.rcParams['grid.color'] = conf["couleurs"]["grille"]
    plt.rcParams['legend.edgecolor'] = conf["couleurs"]["grille"]

    #warning("bla"+str(liste_data_labels),liste_err)  
    for (i,label,couleur) in liste_data_labels:
        plt.plot(coljour,extraire_colonne(t,i,jour_maxi),label=label,color=couleur)
        #warning("colonne"+str(i)+str(label)+str(couleur),liste_err)

    debug("cree_figure : tracé des courbes OMS ok",liste_err) 
    
    # On extrait la valeur min et la valeur max des poids
    (colonne_min,_,_) = liste_data_labels[-1]
    (colonne_max,_,_) = liste_data_labels[0]
    
    poids_min = min(extraire_colonne(t,colonne_min,jour_maxi))
    poids_max = max(extraire_colonne(t,colonne_max,jour_maxi))
    if l_jours != []:
        poids_min = min(min(l_poids),poids_min)
        poids_max = max(max(l_poids),poids_max)
    # On ajuste un peu ces min et max
    # min : valeur min -1kg
    poids_min = max(0,poids_min-1)
    #max : +5% 
    poids_max = poids_max * 1.05
    
    #warning("Jusque là ça marche",liste_err)
    debug("cree_figure : prête à tracer la courbe de l'enfant",liste_err)
    
    if l_jours != []:
        plt.plot(l_jours_conv,l_poids,label=conf["nom"],color=conf["couleurs"]["cadretxt"],marker='o')
    
    plt.xlabel("Âge en "+conf["unite"],color=conf["couleurs"]["cadretxt"])
    plt.ylabel("Poids en kg",color=conf["couleurs"]["cadretxt"])
    plt.title(titre,color=conf["couleurs"]["cadretxt"])
    plt.axis([0,age_maxi,poids_min,poids_max])
    
    if conf['legende']=="oui":
        legende = plt.legend(loc=conf['positionlegende'])
        plt.setp(legende.get_texts(), color=conf["couleurs"]["cadretxt"])
    plt.grid(conf["grille"]=="oui")

    fig.tight_layout()
    
    #warning("Jusque là ça marche",liste_err)
    return fig